==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/sitevpnpolicy/vpnpolicylist/vpnpolicy/entries/filter/lan/lanprefix/lanprefixes/Ipv4LanPrefixesKeys.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.sitevpnpolicy.vpnpolicylist.vpnpolicy.entries.filter.lan.lanprefix.lanprefixes;

import org.onosproject.yang.gen.v1.yrtietfinettypes.rev20130715.yrtietfinettypes.Ipv4Prefix;
import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of ipv4LanPrefixes.
 */
public class Ipv4LanPrefixesKeys implements KeyInfo<DefaultIpv4LanPrefixes> {
    protected Ipv4Prefix lan;
    /**
     * Returns the attribute lan.
     *
     * @return lan value of lan
     */
    public Ipv4Prefix lan() {
        return lan;
    }

    /**
     * Sets the value to attribute lan.
     *
     * @param lan value of lan
     */
    public void lan(Ipv4Prefix lan) {
        this.lan = lan;
    }


    @Override
    public int hashCode() {
        return Objects.hash(lan);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof Ipv4LanPrefixesKeys) {
            Ipv4LanPrefixesKeys other = (Ipv4LanPrefixesKeys) obj;
            return
                Objects.equals(lan, other.lan);
        }
        return false;
    }
}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/sitevpnpolicy/vpnpolicylist/vpnpolicy/entries/filter/lan/lanprefix/lanprefixes/Ipv4LanPrefixesKeys.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.sitevpnpolicy.vpnpolicylist.vpnpolicy.entries.filter.lan.lanprefix.lanprefixes;

import org.onosproject.yang.gen.v1.yrtietfinettypes.rev20130715.yrtietfinettypes.Ipv4Prefix;
import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of ipv4LanPrefixes.
 */
public class Ipv4LanPrefixesKeys implements KeyInfo<DefaultIpv4LanPrefixes> {
    protected Ipv4Prefix lan;
    /**
     * Returns the attribute lan.
     *
     * @return lan value of lan
     */
    public Ipv4Prefix lan() {
        return lan;
    }

    /**
     * Sets the value to attribute lan.
     *
     * @param lan value of lan
     */
    public void lan(Ipv4Prefix lan) {
        this.lan = lan;
    }


    @Override
    public int hashCode() {
        return Objects.hash(lan);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof Ipv4LanPrefixesKeys) {
            Ipv4LanPrefixesKeys other = (Ipv4LanPrefixesKeys) obj;
            return
                Objects.deepEquals(lan, other.lan);
        }
        return false;
    }
}
